==> blender-2.31.tar.gz: blender-2.31/source/gameengine/Ketsji/KX_RayEventManager.h <==
/**
 * Manager for ray events
 *
 * $Id: KX_RayEventManager.h,v 1.5 2002/12/27 13:10:48 mein Exp $
 *
 * ***** BEGIN GPL/BL DUAL LICENSE BLOCK *****
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version. The Blender
 * Foundation also sells licenses for use in proprietary software under
 * the Blender License.  See http://www.blender.org/BL/ for information
 * about this.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 *
 * The Original Code is Copyright (C) 2001-2002 by NaN Holding BV.
 * All rights reserved.
 *
 * The Original Code is: all of this file.
 *
 * Contributor(s): none yet.
 *
 * ***** END GPL/BL DUAL LICENSE BLOCK *****
 */

#ifndef __KX_RAYEVENTMGR
#define __KX_RAYEVENTMGR
#include "SCA_EventManager.h"
#include <vector>
using namespace std;

class KX_RayEventManager : public SCA_EventManager
{

	class SCA_LogicManager* m_logicmgr;
public:
	KX_RayEventManager(class SCA_LogicManager* logicmgr)
		: m_logicmgr(logicmgr),
		SCA_EventManager(RAY_EVENTMGR)
	{}
	virtual void NextFrame(double curtime,double deltatime);
	virtual void	RegisterSensor(SCA_ISensor* sensor);
};

#endif //__KX_RAYEVENTMGR

==> blender-2.46.tar.gz: blender-2.46/source/gameengine/Ketsji/KX_RayEventManager.h <==
/**
 * Manager for ray events
 *
 * $Id: KX_RayEventManager.h 14444 2008-04-16 22:40:48Z hos $
 *
 * ***** BEGIN GPL LICENSE BLOCK *****
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 *
 * The Original Code is Copyright (C) 2001-2002 by NaN Holding BV.
 * All rights reserved.
 *
 * The Original Code is: all of this file.
 *
 * Contributor(s): none yet.
 *
 * ***** END GPL LICENSE BLOCK *****
 */

#ifndef __KX_RAYEVENTMGR
#define __KX_RAYEVENTMGR
#include "SCA_EventManager.h"
#include <vector>
using namespace std;

class KX_RayEventManager : public SCA_EventManager
{

	class SCA_LogicManager* m_logicmgr;
public:
	KX_RayEventManager(class SCA_LogicManager* logicmgr)
		: SCA_EventManager(RAY_EVENTMGR),
		  m_logicmgr(logicmgr)
	{}
	virtual void NextFrame();
	virtual void	RegisterSensor(SCA_ISensor* sensor);
};

#endif //__KX_RAYEVENTMGR
